@@ -18,19 +18,27 @@ sub new {
 	bless($self, $class);
 
 	my $pre_selection = [$pkg_match, $sub_match];
-	if(ref($pkg_match) eq '') {
+
+	my $match_ref = ref($pkg_match);
+	if($match_ref eq '') {
 		$pre_selection->[0] =~ s/\w*[^\w\:].*$//s;
+	} elsif ($match_ref eq 'CODE') {
+		$pre_selection->[0] = ''; # unless we have a matching object
 	}
-	if(ref($sub_match) eq '') {
+
+	$match_ref = ref($sub_match);
+	if($match_ref eq '') {
 		$pre_selection->[1] = '';
 		if ($sub_match =~ m/^([a-z0-9]*_)/i) {
 			$pre_selection->[1] = $1 || '';
 		}
+	} elsif ($match_ref eq 'CODE') {
+		$pre_selection->[1] = '';
 	}
 	$self->[ATB_PRE_SELECT] = $pre_selection;
 
-	$self->[ATB_PKG_MATCH] = $self->create_matcher($pkg_match, '::');
-	$self->[ATB_SUB_MATCH] = $self->create_matcher($sub_match, '_');
+	$self->[ATB_PKG_MATCH] = $self->create_matcher(0, $pkg_match, '::');
+	$self->[ATB_SUB_MATCH] = $self->create_matcher(1, $sub_match, '_');
 
 	Internals::SvREADONLY(@{$self}, 1);
 	return($self);
@@ -43,21 +51,24 @@ sub pre_select {
 
 
 sub create_matcher {
-	my ($self, $name, $separator) = (shift, shift, shift);
+	my ($self, $i, $name, $separator) = (shift, shift, shift, shift);
 
 	my $matcher;
-	if (ref($name) eq 'ARRAY') {
-		$matcher = sub { scalar(grep($_ eq $_[0], @$name)) > 0 };
+	my $name_ref = ref($name);
+	if ($name_ref eq 'ARRAY') {
+		$matcher = sub { scalar(grep($_ eq $_[$i], @$name)) > 0 };
+	} elsif ($name_ref eq 'CODE') {
+		$matcher = $name;
 	} elsif (length($name) == 0) {
 		$matcher = sub { 1 };
 	} elsif ($name =~ m,[^\w\:],) {
-		$matcher = sub { $_[0] =~ m,$name,o };
-	} elsif ((substr($name, -2, 2) eq $separator)
-	or(substr($name, -1, 1) eq $separator)) {
+		$matcher = sub { $_[$i] =~ m,$name,o };
+	} elsif ($matcher = length($separator)
+	and (substr($name, -$matcher, $matcher) eq $separator)) {
 		my $l = length($name);
-		$matcher = sub { ($name eq substr($_[0], 0, $l)) };
+		$matcher = sub { ($name eq substr($_[$i], 0, $l)) };
 	} else {
-		$matcher = sub { ($_[0] eq $name) };
+		$matcher = sub { ($_[$i] eq $name) };
 	}
 
 	return($matcher);
@@ -67,8 +78,8 @@ sub create_matcher {
 sub check {
 	my ($self, $pkg_name, $sub_name) = (shift, shift, shift);
 
-	return(undef) unless ($self->[ATB_PKG_MATCH]->($pkg_name));
-	return(undef) unless ($self->[ATB_SUB_MATCH]->($sub_name));
+	return(undef) unless ($self->[ATB_PKG_MATCH]->($pkg_name, $sub_name, @_));
+	return(undef) unless ($self->[ATB_SUB_MATCH]->($pkg_name, $sub_name, @_));
 
 	if (defined($self->[ATB_ARGC_MATCH])
 	and ($self->[ATB_ARGC_MATCH] != scalar(@_))) {
